@@ -279,9 +279,12 @@ class Config(object):
             log = logging.getLogger('argtoolbox')
             log.debug("reloading configuration ...")
             if args.config_file:
-                self.file_parser.read(args.config_file)
+                self.file_parser = ConfigParser.SafeConfigParser()
+                discoveredFileList = self.file_parser.read(args.config_file)
+                log.debug("discoveredFileList: " + str(discoveredFileList))
             for s in self.sections.values():
                 log.debug("loading section : " + s.get_section_name())
+                s.reset()
                 s.load(self.file_parser)
             log.debug("configuration reloaded.")
 
@@ -421,6 +424,10 @@ class _Section(_AbstractSection):
         Section"""
         return len(self.elements)
 
+    def reset(self):
+        for e in self.elements.values():
+            e.reset()
+
     def load(self, file_parser):
         section = self.get_section_name()
         try:
@@ -535,6 +542,10 @@ class ListSection(_AbstractSection):
             else:
                 log.debug("Missing section : " + section)
 
+    def reset(self):
+        for e in self.elements.values():
+            e.reset()
+
     def get_representation(self, prefix="", suffix="\n"):
         res = []
         res.append(prefix + "Section " + self._name + suffix)
@@ -766,6 +777,9 @@ config file." % {"name": self._name}
             else:
                 log.debug("Field not found : '" + self._name + "'")
 
+    def reset(self):
+        self.value = None
+
     def get_arg_parse_arguments(self):
         """
         During the element declaration, all configuration file requirements
